@@ -118,7 +118,7 @@ func verifyOperatorUp(t *testing.T) *samplesapi.Config {
 	var cfg *samplesapi.Config
 	var err error
 	err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -152,7 +152,7 @@ func verifySecretPresent(t *testing.T) {
 
 func verifyConditionsCompleteSamplesAdded(t *testing.T) error {
 	return wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err := crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -171,7 +171,7 @@ func verifyConditionsCompleteSamplesAdded(t *testing.T) error {
 
 func verifyConditionsCompleteSamplesRemoved(t *testing.T) error {
 	return wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err := crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -185,7 +185,7 @@ func verifyConditionsCompleteSamplesRemoved(t *testing.T) error {
 	})
 }
 
-func verifyClusterOperatorConditionsComplete(t *testing.T, expectedVersion string) {
+func verifyClusterOperatorConditionsComplete(t *testing.T, expectedVersion string, mgmtCfg operatorsv1api.ManagementState) {
 	var state *configv1.ClusterOperator
 	var err error
 	err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
@@ -194,28 +194,41 @@ func verifyClusterOperatorConditionsComplete(t *testing.T, expectedVersion strin
 			t.Logf("%v", err)
 			return false, nil
 		}
-		availableOK, progressingOK, failingOK, versionOK := false, false, false, false
+		availableOK, progressingOK, degradedOK, versionOK, reasonOK := false, false, false, false, false
+		availableReason, progressingReason, degradedReason := "", "", ""
 		for _, condition := range state.Status.Conditions {
 			switch condition.Type {
 			case configv1.OperatorAvailable:
 				if condition.Status == configv1.ConditionTrue {
 					availableOK = true
 				}
+				availableReason = condition.Reason
 			case configv1.OperatorDegraded:
 				if condition.Status == configv1.ConditionFalse {
-					failingOK = true
+					degradedOK = true
 				}
+				degradedReason = condition.Reason
 			case configv1.OperatorProgressing:
 				if condition.Status == configv1.ConditionFalse {
 					progressingOK = true
 				}
+				progressingReason = condition.Reason
 			}
 		}
 		if len(state.Status.Versions) > 0 && state.Status.Versions[0].Name == "operator" && state.Status.Versions[0].Version == expectedVersion {
 			versionOK = true
 		}
 
-		if availableOK && progressingOK && failingOK && versionOK {
+		if mgmtCfg != operatorsv1api.Managed {
+			goodValue := "Currently" + string(mgmtCfg)
+			if availableReason == goodValue && progressingReason == goodValue && degradedReason == goodValue {
+				reasonOK = true
+			}
+		} else {
+			reasonOK = true
+		}
+
+		if availableOK && progressingOK && degradedOK && versionOK && reasonOK {
 			return true, nil
 		}
 		return false, nil
@@ -370,7 +383,7 @@ func verifyImageChangesInProgress(t *testing.T) {
 	var cfg *samplesapi.Config
 	var err error
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -457,7 +470,7 @@ func validateContent(t *testing.T, timeToCompare *kapis.Time) {
 
 func verifyConfigurationValid(t *testing.T, status corev1.ConditionStatus) {
 	err := wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, e := crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, e := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if e != nil {
 			t.Logf("%v", e)
 			return false, nil
@@ -647,47 +660,52 @@ func TestImageStreamInOpenshiftNamespace(t *testing.T) {
 		t.Fatalf("Config did not stabilize on startup %#v", verifyOperatorUp(t))
 	}
 	verifySecretPresent(t)
-	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version)
+	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version, cfg.Status.ManagementState)
 	t.Logf("Config after TestImageStreamInOpenshiftNamespace: %#v", verifyOperatorUp(t))
 }
 
 func TestRecreateConfigAfterDelete(t *testing.T) {
-	cfg := verifyOperatorUp(t)
-
-	oldTime := cfg.CreationTimestamp
 	now := kapis.Now()
+	// do a few deletes/recreates in rapid succession vs. a single iteration to make
+	// sure we cover the various timing windows when samples creation is in progress
+	for i := 0; i < 3; i++ {
+		cfg := verifyOperatorUp(t)
 
-	err := crClient.Samples().Configs().Delete(samplesapi.ConfigName, &metav1.DeleteOptions{})
-	if err != nil {
-		dumpPod(t)
-		t.Fatalf("error deleting Config %v", err)
-	}
+		oldTime := cfg.CreationTimestamp
 
-	err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		err := crClient.SamplesV1().Configs().Delete(samplesapi.ConfigName, &metav1.DeleteOptions{})
 		if err != nil {
-			return false, nil
+			dumpPod(t)
+			t.Fatalf("error deleting Config %v", err)
 		}
-		if cfg.CreationTimestamp == oldTime {
-			return false, nil
+
+		// make sure the cfg object is recreated vs. just finding the one we  tried to delete
+		err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
+			cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+			if err != nil {
+				return false, nil
+			}
+			if cfg.CreationTimestamp == oldTime {
+				return false, nil
+			}
+			return true, nil
+		})
+		if err != nil {
+			dumpPod(t)
+			t.Fatalf("creation times the same after delete: %v, %v, %#v", oldTime, cfg.CreationTimestamp, cfg)
 		}
-		return true, nil
-	})
-	if err != nil {
-		dumpPod(t)
-		t.Fatalf("creation times the same after delete: %v, %v, %#v", oldTime, cfg.CreationTimestamp, cfg)
 	}
 
-	err = verifyConditionsCompleteSamplesAdded(t)
+	err := verifyConditionsCompleteSamplesAdded(t)
 	if err != nil {
 		dumpPod(t)
-		cfg = verifyOperatorUp(t)
+		cfg := verifyOperatorUp(t)
 		t.Fatalf("samples not re-established after delete %#v", cfg)
 	}
 
 	validateContent(t, &now)
-	cfg = verifyOperatorUp(t)
-	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version)
+	cfg := verifyOperatorUp(t)
+	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version, cfg.Status.ManagementState)
 	t.Logf("Config after TestRecreateConfigAfterDelete: %#v", cfg)
 }
 
@@ -698,7 +716,7 @@ func TestSpecManagementStateField(t *testing.T) {
 	err := retry.RetryOnConflict(retry.DefaultBackoff, func() error {
 		cfg := verifyOperatorUp(t)
 		cfg.Spec.ManagementState = operatorsv1api.Removed
-		cfg, err := crClient.Samples().Configs().Update(cfg)
+		cfg, err := crClient.SamplesV1().Configs().Update(cfg)
 		return err
 	})
 	if err != nil {
@@ -706,7 +724,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		t.Fatalf("error updating Config %v and %#v", err, verifyOperatorUp(t))
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -729,7 +747,7 @@ func TestSpecManagementStateField(t *testing.T) {
 	}
 
 	err = wait.PollImmediate(1*time.Second, 10*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -748,12 +766,12 @@ func TestSpecManagementStateField(t *testing.T) {
 	verifyImageStreamsGone(t)
 	verifyTemplatesGone(t)
 
-	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version)
+	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version, cfg.Status.ManagementState)
 
 	err = retry.RetryOnConflict(retry.DefaultBackoff, func() error {
 		cfg = verifyOperatorUp(t)
 		cfg.Spec.ManagementState = operatorsv1api.Managed
-		cfg, err = crClient.Samples().Configs().Update(cfg)
+		cfg, err = crClient.SamplesV1().Configs().Update(cfg)
 		return err
 	})
 	if err != nil {
@@ -761,7 +779,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		t.Fatalf("error updating Config %v and %#v", err, cfg)
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -788,7 +806,7 @@ func TestSpecManagementStateField(t *testing.T) {
 	err = retry.RetryOnConflict(retry.DefaultBackoff, func() error {
 		cfg = verifyOperatorUp(t)
 		cfg.Spec.ManagementState = operatorsv1api.Unmanaged
-		cfg, err = crClient.Samples().Configs().Update(cfg)
+		cfg, err = crClient.SamplesV1().Configs().Update(cfg)
 		return err
 	})
 	if err != nil {
@@ -796,7 +814,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		t.Fatalf("error updating Config %v", err)
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -813,7 +831,7 @@ func TestSpecManagementStateField(t *testing.T) {
 
 	verifyDeletedImageStreamNotRecreated(t)
 	verifyDeletedTemplatesNotRecreated(t)
-	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version)
+	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version, cfg.Status.ManagementState)
 
 	// get timestamp to check against in progress condition
 	now = kapis.Now()
@@ -822,7 +840,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		// and confirm all the default samples content exists
 		cfg = verifyOperatorUp(t)
 		cfg.Spec.ManagementState = operatorsv1api.Managed
-		cfg, err = crClient.Samples().Configs().Update(cfg)
+		cfg, err = crClient.SamplesV1().Configs().Update(cfg)
 		return err
 	})
 	if err != nil {
@@ -830,7 +848,7 @@ func TestSpecManagementStateField(t *testing.T) {
 		t.Fatalf("error updating Config %v and %#v", err, cfg)
 	}
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -847,7 +865,7 @@ func TestSpecManagementStateField(t *testing.T) {
 
 	// wait for it to get into pending
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err = crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err = crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -870,7 +888,7 @@ func TestSpecManagementStateField(t *testing.T) {
 	}
 
 	validateContent(t, nil)
-	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version)
+	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version, cfg.Status.ManagementState)
 	t.Logf("Config after TestSpecManagementStateField: %#v", verifyOperatorUp(t))
 }
 
@@ -884,7 +902,7 @@ func TestSkippedProcessing(t *testing.T) {
 		cfg := verifyOperatorUp(t)
 		cfg.Spec.SkippedImagestreams = append(cfg.Spec.SkippedImagestreams, "jenkins")
 		cfg.Spec.SkippedTemplates = append(cfg.Spec.SkippedTemplates, "jenkins-ephemeral")
-		cfg, err := crClient.Samples().Configs().Update(cfg)
+		cfg, err := crClient.SamplesV1().Configs().Update(cfg)
 		return err
 	})
 	if err != nil {
@@ -914,7 +932,7 @@ func TestSkippedProcessing(t *testing.T) {
 		cfg := verifyOperatorUp(t)
 		cfg.Spec.SkippedImagestreams = []string{}
 		cfg.Spec.SkippedTemplates = []string{}
-		cfg, err = crClient.Samples().Configs().Update(cfg)
+		cfg, err = crClient.SamplesV1().Configs().Update(cfg)
 		return err
 	})
 	if err != nil {
@@ -923,7 +941,7 @@ func TestSkippedProcessing(t *testing.T) {
 	}
 	// verify status skipped has been reset
 	err = wait.PollImmediate(1*time.Second, 3*time.Minute, func() (bool, error) {
-		cfg, err := crClient.Samples().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
+		cfg, err := crClient.SamplesV1().Configs().Get(samplesapi.ConfigName, metav1.GetOptions{})
 		if err != nil {
 			t.Logf("%v", err)
 			return false, nil
@@ -1041,7 +1059,7 @@ func coreTestUpgrade(t *testing.T) {
 		return false, nil
 	})
 
-	verifyClusterOperatorConditionsComplete(t, newVersion)
+	verifyClusterOperatorConditionsComplete(t, newVersion, cfg.Status.ManagementState)
 
 	if cfg.Status.ManagementState == operatorsv1api.Managed {
 		validateContent(t, nil)
